/**
 * Program skeleton for the course "Programming embedded systems"
 */

#include <stdio.h>

/* Scheduler includes. */
#include "FreeRTOS.h"
#include "stm32f10x_conf.h"
#include "stm32f10x_lib.h"
#include "stm32f10x_tim.h"
#include "stm32f10x_map.h"
#include "task.h"
#include "setup.h"
#include "assert.h"

/*-----------------------------------------------------------*/

void task(void *params) {
  TIM_TimeBaseInitTypeDef timInit;
  TIM_OCInitTypeDef TIM_OCInitStruct;

  /* Setup timer TIM3 for pulse-width modulation:
     100kHz, periodically counting from 0 to 9999 */
  RCC_APB1PeriphClockCmd( RCC_APB1Periph_TIM3, ENABLE );

  TIM_DeInit( TIM3 );
  TIM_TimeBaseStructInit( &timInit );

  timInit.TIM_Period = (unsigned portSHORT)0x270F; // Auto-reload period
  timInit.TIM_Prescaler = 719;                     // Prescaler; resulting frequency
                                                   //  is 72MHz / 720 = 100kHz
  timInit.TIM_CounterMode = TIM_CounterMode_Up;    // Counting upwards
    
  TIM_TimeBaseInit( TIM3, &timInit );
  TIM_ARRPreloadConfig( TIM3, ENABLE );

  TIM_OCStructInit(&TIM_OCInitStruct);
  TIM_OCInitStruct.TIM_OCMode = TIM_OCMode_PWM1;
  TIM_OCInitStruct.TIM_OCPolarity = 1;
  TIM_OCInitStruct.TIM_Pulse = 4000;

  TIM_OCInitStruct.TIM_Channel = TIM_Channel_1;
  TIM_OCInit(TIM3, &TIM_OCInitStruct);

  TIM_Cmd(TIM3, ENABLE);

  for (;;);
}

/*
 * Entry point of program execution
 */
int main( void )
{
  prvSetupHardware();

  xTaskCreate(task, "timer", 100, NULL, 1, NULL);

  vTaskStartScheduler();
  assert(0);
  return 0;                 // not reachable
}
/*-----------------------------------------------------------*/


